@@ -1,5 +1,5 @@
 //
-// Copyright 2010-2013 Ettus Research LLC
+// Copyright 2010-2014 Ettus Research LLC
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -79,7 +79,10 @@ template <class T> struct to_hex{
 //!parse hex-formatted ASCII text into an int
 boost::uint16_t atoh(const std::string &string){
     if (string.substr(0, 2) == "0x"){
-        return boost::lexical_cast<to_hex<boost::uint16_t> >(string);
+        std::stringstream interpreter(string);
+        to_hex<boost::uint16_t> hh;
+        interpreter >> hh;
+        return hh.value;
     }
     return boost::lexical_cast<boost::uint16_t>(string);
 }
@@ -173,7 +176,7 @@ uhd::transport::usb_device_handle::sptr open_device(const boost::uint16_t vid, c
     catch(const std::exception &e) {
         std::cerr << "Failed to communicate with the device!" << std::endl;
         #ifdef UHD_PLATFORM_WIN32
-        std::cerr << "The necessary drivers are not installed. Read the UHD Transport Application Notes for details:\nhttp://files.ettus.com/uhd_docs/manual/html/transport.html" << std::endl;
+        std::cerr << "The necessary drivers are not installed. Read the UHD Transport Application Notes for details:\nhttp://files.ettus.com/manual/page_transport.html" << std::endl;
         #endif /* UHD_PLATFORM_WIN32 */
         handle.reset();
     }
@@ -195,7 +198,7 @@ b200_iface::sptr make_b200_iface(const uhd::transport::usb_device_handle::sptr &
     catch(const std::exception &e) {
         std::cerr << "Failed to communicate with the device!" << std::endl;
         #ifdef UHD_PLATFORM_WIN32
-        std::cerr << "The necessary drivers are not installed. Read the UHD Transport Application Notes for details:\nhttp://files.ettus.com/uhd_docs/manual/html/transport.html" << std::endl;
+        std::cerr << "The necessary drivers are not installed. Read the UHD Transport Application Notes for details:\nhttp://files.ettus.com/manual/page_transport.html" << std::endl;
         #endif /* UHD_PLATFORM_WIN32 */
         b200.reset();
     }
@@ -532,7 +535,7 @@ boost::int32_t main(boost::int32_t argc, char *argv[]) {
 
     } else if (vm.count("load-fpga")) {
         std::cout << "Loading FPGA image (" << fpga_file << ")" << std::endl;
-        uint32_t fx3_state;
+        boost::uint32_t fx3_state;
         try {fx3_state = b200->load_fpga(fpga_file);} // returns 0 on success, or FX3 state on error
         catch (uhd::exception &e) {
             std::cerr << "Exception while loading FPGA: " << e.what() << std::endl;
